@@ -3,51 +3,11 @@ package String::InterpolatedVariables;
 use strict;
 use warnings;
 
+our $VERSION = '2.000000';
+
 use Readonly;
 
 
-=head1 NAME
-
-String::InterpolatedVariables - Extract variable names from interpolated strings.
-
-
-=head1 VERSION
-
-Version 1.1.0
-
-=cut
-
-our $VERSION = '1.1.0';
-
-
-=head1 SYNOPSIS
-
-	use String::InterpolatedVariables;
-
-	my $variables = String::InterpolatedVariables::extract(
-		'A $test->{string} from a PPI::Token::Quote::Double $object.'
-	);
-
-	# $variables now contains:
-	# [
-	#     '$test->{string}',
-	#     '$object',
-	# ]
-
-
-=head1 DESCRIPTION
-
-String::InterpolatedVariables offers a way to extract the name of the variables
-that are present in interpolated strings.
-
-This is particularly useful if you are using L<PPI> to parse Perl documents,
-and you want to know what variables would be interpolated inside the
-L<PPI::Token::Quote::Double> and L<PPI::Token::Quote::Interpolate> objects you
-find there. A practical example of this use can be found in
-L<Perl::Critic::Policy::ValuesAndExpressions::PreventSQLInjection>.
-
-=cut
-
 Readonly::Scalar my $VARIABLES_REGEX => qr/
 	# Ignore escaped sigils, since those wouldn't get interpreted as variables to interpolate.
 	(?<!\\)
@@ -80,6 +40,58 @@ Readonly::Scalar my $VARIABLES_REGEX => qr/
 /x;
 
 
+sub extract {
+    my ($string) = @_;
+
+    my $variables = [];
+    while ( my ($variable) = $string =~ $VARIABLES_REGEX ) {
+        push( @$variables, $variable );
+        $string =~ s/\Q$variable\E//g;
+    }
+
+    return $variables;
+}
+
+
+1;
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+String::InterpolatedVariables - Extract variable names from interpolated strings.
+
+=head1 VERSION
+
+version 2.000000
+
+=head1 SYNOPSIS
+
+	use String::InterpolatedVariables;
+
+	my $variables = String::InterpolatedVariables::extract(
+		'A $test->{string} from a PPI::Token::Quote::Double $object.'
+	);
+
+	# $variables now contains:
+	# [
+	#     '$test->{string}',
+	#     '$object',
+	# ]
+
+=head1 DESCRIPTION
+
+String::InterpolatedVariables offers a way to extract the name of the variables
+that are present in interpolated strings.
+
+This is particularly useful if you are using L<PPI> to parse Perl documents,
+and you want to know what variables would be interpolated inside the
+L<PPI::Token::Quote::Double> and L<PPI::Token::Quote::Interpolate> objects you
+find there. A practical example of this use can be found in
+L<Perl::Critic::Policy::ValuesAndExpressions::PreventSQLInjection>.
+
 =head1 FUNCTIONS
 
 =head2 extract()
@@ -104,23 +116,6 @@ useful if you are using using a tool such as L<PPI> to read Perl code, since
 PPI will give you access to the text of the string itself for strings that
 would otherwise be interpolated during execution.
 
-=cut
-
-sub extract
-{
-	my ( $string ) = @_;
-
-	my $variables = [];
-	while ( my ( $variable ) = $string =~ $VARIABLES_REGEX )
-	{
-		push( @$variables, $variable );
-		$string =~ s/\Q$variable\E//g;
-	}
-
-	return $variables;
-}
-
-
 =head1 BUGS
 
 Please report any bugs or feature requests through the web interface at
@@ -128,29 +123,19 @@ L<https://github.com/guillaumeaubert/String-InterpolatedVariables/issues>.
 I will be notified, and then you'll automatically be notified of progress on
 your bug as I make changes.
 
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
 	perldoc String::InterpolatedVariables
 
-
 You can also look for information at:
 
 =over 4
 
 =item * GitHub (report bugs there)
 
-L<https://github.com/guillaumeaubert/String-InterpolatedVariables/issues>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/String-InterpolatedVariables>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/String-InterpolatedVariables>
+L<https://github.com/oalders/String-InterpolatedVariables/issues>
 
 =item * MetaCPAN
 
@@ -158,24 +143,18 @@ L<https://metacpan.org/release/String-InterpolatedVariables>
 
 =back
 
-
 =head1 AUTHOR
 
-L<Guillaume Aubert|https://metacpan.org/author/AUBERTG>,
-C<< <aubertg at cpan.org> >>.
+Guillaume Aubert <aubertg@cpan.org>
 
+=head1 COPYRIGHT AND LICENSE
 
-=head1 COPYRIGHT & LICENSE
+This software is copyright (c) 2014 by Guillaume Aubert.
 
-Copyright 2014-2017 Guillaume Aubert.
-
-This code is free software; you can redistribute it and/or modify it under the
-same terms as Perl 5 itself.
-
-This program is distributed in the hope that it will be useful, but WITHOUT ANY
-WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-PARTICULAR PURPOSE. See the LICENSE file for more details.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1;
+__END__
+# ABSTRACT: Extract variable names from interpolated strings.
